<?php

/**
 * Content width
 */

if ( ! isset( $content_width ) )
	$content_width = 1170;

/**
 * Theme setup
 */

add_action( 'after_setup_theme', 'tz_theme_setup' );
function tz_theme_setup() {
	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// Title tag
	add_theme_support( 'title-tag' );

	// Register WP 3.0+ Menus
	register_nav_menus( array( 'primary-menu' => __( 'Primary Menu', 'jewelry' ) ) );

	// Post thumbnail support
	add_theme_support( 'post-thumbnails' );

	// Add woocommerce support
	add_theme_support( 'woocommerce' );

	// Custom image size
	add_image_size( 'tz_home_product_thumb', 194, 210, true );
	add_image_size( 'tz_cart_product_thumb', 112, 112, true );
}

/**
 * Adding custom image sizes to media uploader
 */

add_filter( 'image_size_names_choose', 'tz_image_sizes' );
function tz_image_sizes( $sizes ) {
	$add_sizes = array(
		"tz_home_product_thumb" => __( 'Home Product Thumb', 'jewelry' )
	);
	$new_sizes = array_merge( $sizes, $add_sizes );

	return $new_sizes;
}

/**
 * Get image
 */

function tz_get_image( $post_id, $size, $id = false ) {
	$post = get_children(
		array(
			'post_parent' => $post_id,
			'post_type'   => 'attachment',
			'numberposts' => 1
		)
	);

	if ( $post ) {
		foreach( $post as $p ) {
			$attachment_id = $p->ID;
			$attachment = wp_get_attachment_image_src( $attachment_id, $size );
		}

		if ( isset( $attachment ) && $attachment ) {
			if ( $id )
				return $attachment_id;

			return $attachment[0];
		}
	}
}

/**
 * Load styles
 */

add_action( 'wp_enqueue_scripts', 'tz_enqueue_styles' );
function tz_enqueue_styles() {
  //wp_enqueue_style( 'tz-gf', 'http://fonts.googleapis.com/css?family=Titillium+Web:200,300,400,700', false );
	wp_enqueue_style( 'tz-style', get_stylesheet_uri() );
	wp_enqueue_style( 'tz-fa', get_template_directory_uri() . '/assets/fonts/font-awesome.min.css' );
}

/**
 * Load scripts
 */

add_action( 'wp_enqueue_scripts', 'tz_enqueue_scripts' );
function tz_enqueue_scripts() {
	wp_register_script( 'jquery-min', get_template_directory_uri() . '/assets/scripts/jquery-1.11.1.min.js', 'jquery', '1.11.1', TRUE );
	wp_register_script( 'plugins', get_template_directory_uri() . '/assets/scripts/plugins.js', 'jquery', '0.0.1', TRUE );
	wp_register_script( 'main', get_template_directory_uri() . '/assets/scripts/main.js', 'jquery', '0.0.1', TRUE );

	wp_enqueue_script( 'jquery-min' );
	wp_enqueue_script( 'plugins' );
	wp_enqueue_script( 'main' );

	if ( is_single() )
		wp_enqueue_script( 'comment-reply' );

	$min_price = ( isset( $_GET['min_price'] ) ) ? $_GET['min_price'] : 0;
	$max_price = ( isset( $_GET['max_price'] ) ) ? $_GET['max_price'] : 5000;

	wp_localize_script( 'main', 'tz', array( 'ajax_url' => admin_url( 'admin-ajax.php' ), 'min_price' => $min_price, 'max_price' => $max_price ) );
}

/**
 * Filter search results
 */

add_filter( 'pre_get_posts', 'tz_search_filter' );
function tz_search_filter( $query ) {
	if ( $query->is_search )
		$query->set( 'post_type', 'post' );

	return $query;
}

/**
 * Pagination
 */

function tz_pagination( $range = 2 ) {
	global $wp_query, $paged;

	$showitems = ( $range * 2 ) + 1;
	$paged = ( empty( $paged ) ) ? 1 : $paged;
	$pages = ( ! $wp_query->max_num_pages ) ? 1 : $wp_query->max_num_pages;

  if ( $pages != 1 ) {
		echo '<nav class="pagination clearfix">';
		echo '<ul>';

		echo '<li><a class="previous" href="' . get_pagenum_link( $paged - 1 ) . '"><span class="ico-prev"></span></a></li>';

		for ( $i = 1; $i <= $pages; $i++ ) {
			if ( $pages != 1 && ( ! ( $i >= $paged + $range + 1 || $i <= $paged - $range - 1 ) || $pages <= $showitems ) ) {
				echo '<li', ( $paged == $i ) ? ' class="active"' : '', '>';
				echo '<a href="' . get_pagenum_link( $i ) . '">' . $i . '</a>';
				echo '</li>';
			}
		}

		echo '<li><a class="next" href="' . get_pagenum_link( $paged + 1 ) . '"><span class="ico-next"></span></a></li>';

		echo '</ul>';
    echo '</nav>' . "\n";
  }
}

/**
 * Contact Form
 */

add_action( 'wp_ajax_nopriv_tz_contact_form', 'tz_ajax_contact_form' );
add_action( 'wp_ajax_tz_contact_form', 'tz_ajax_contact_form' );
function tz_ajax_contact_form() {
	$params = array();

	parse_str( $_POST['data'], $params );

	$name = trim( $params['name'] );
	$email = $params['email'];
	$phone = $params['phone'];
	$street = $params['street'];
	$city = $params['city'];
	$subject = $params['subject'];
	$admin_email = ( get_theme_mod( 'tz_contact_email' ) ) ? get_theme_mod( 'tz_contact_email' ) : get_option( 'admin_email' );

	if ( $subject == "" )
		$subject = __( 'A message from contact form at ', 'jewelry' ) . get_bloginfo( 'name' );

	if ( $name == "" )
		$error['name'] = '<div class="message error">' . __( 'Please enter your name', 'jewelry' ) . '</div>';

	if ( ! is_email( trim( $email ) ) )
		$error['email'] = '<div class="message error">' . __( 'Your email is invalid', 'jewelry' ) . '</div>';

	if ( $phone == "" )
		$error['phone'] = '<div class="message error">' . __( 'Please enter your phone', 'jewelry' ) . '</div>';

	if ( $street == "" )
		$error['street'] = '<div class="message error">' . __( 'Please enter your street address', 'jewelry' ) . '</div>';

	if ( $city == "" )
		$error['city'] = '<div class="message error">' . __( 'Please enter your city', 'jewelry' ) . '</div>';

	if ( ! isset( $error ) ) {
		$body = 'Name: ' . $name . "\n\n";
		$body.= 'Email: ' . $email . "\n\n";
		$body.= 'Phone: ' . $phone . "\n\n";
		$body.= 'Street: ' . $street . "\n\n";
		$body.= 'City: ' . $city . "\n\n";
		$headers = 'From: ' . $name . ' <' . $email . '>' . "\r\n";
		$headers.= 'Reply-To: ' . $email;
		wp_mail( $admin_email, $subject, $body, $headers );
		$success['success'] = '<div class="message success">' . __( 'Thank you! Your message will be replied soon.', 'jewelry' ) . '</div>';
		echo json_encode( $success );
	} else {
		echo json_encode( $error );
	}

	exit();
}

/**
 * Custom body class
 */

add_filter( 'body_class', 'custom_body_class' );
function custom_body_class( $classes ) {
	if ( is_home() || is_front_page() ) {
		$classes[] = 'homepage';
	}

	return $classes;
}

/**
 * Custom fragments
 */

add_filter( 'woocommerce_add_to_cart_fragments', 'woocommerce_header_add_to_cart_fragment' );
function woocommerce_header_add_to_cart_fragment( $fragments ) {
 	ob_start();
?>
	<a class="cart-contents" href="<?php echo wc_get_cart_url(); ?>" title="<?php _e( 'View your shopping cart', 'jewelry' ); ?>">
		<span class="ico-products"></span>
		<?php echo sprintf (_n( __( '%d item', 'jewelry' ), __( '%d items', 'jewelry' ), WC()->cart->get_cart_contents_count() ), WC()->cart->get_cart_contents_count() ); ?>,
		<?php echo strip_tags( WC()->cart->get_cart_total() ); ?>
	</a>
<?php
 	$fragments['a.cart-contents'] = ob_get_clean();
 	return $fragments;
}

/**
 * Register widgets
 */

add_action( 'widgets_init', 'tz_widgets_init' );
function tz_widgets_init() {
 	register_sidebar( array (
	 		'name' => __( 'Footer Widgets', 'jewelry' ),
	 		'id' => 'footer-widgets',
	 		'before_widget' => '<article id="%1$s" class="col %2$s">',
	 		'after_widget' => '</article>',
	 		'before_title' => '<h3 class="widget-title">',
	 		'after_title' => '</h3>'
	 	)
	);
}

/**
 * Disabled woocommerce style
 */

add_filter( 'woocommerce_enqueue_styles', 'custom_woo_css' );
function custom_woo_css( $enqueue_styles ) {
	if ( is_front_page() || is_shop() || is_product_category() || is_cart() ) {
		return array();
	}

	return $enqueue_styles;
}

/**
 * Custom post numbers
 */

add_action( 'pre_get_posts', 'set_posts_per_page_cpt' );
function set_posts_per_page_cpt( $query ) {
	if ( ! is_admin() && $query->is_main_query() && is_tax( 'product_cat' ) ) {
		$posts_per_page = ( isset( $_GET['per_page'] ) ) ? $_GET['per_page'] : 8;
  	$query->set( 'posts_per_page', $posts_per_page );
 	}

	if ( class_exists( 'WooCommerce' ) && ! is_admin() && ! is_page() && $query->is_main_query() && is_shop() ) {
		$posts_per_page = ( isset( $_GET['per_page'] ) ) ? $_GET['per_page'] : 8;
  	$query->set( 'posts_per_page', $posts_per_page );
 	}
}

/**
 * Custom sorting
 */

if ( class_exists( 'WooCommerce' ) ) {
	add_filter( 'woocommerce_get_catalog_ordering_args', 'custom_woocommerce_get_catalog_ordering_args' );
	function custom_woocommerce_get_catalog_ordering_args( $args ) {
	  $orderby_value = isset( $_GET['orderby'] ) ? woocommerce_clean( $_GET['orderby'] ) : apply_filters( 'woocommerce_default_catalog_orderby', get_option( 'woocommerce_default_catalog_orderby' ) );

		if ( 'popularity' == $orderby_value ) {
			$args['orderby'] = 'popularity';
			$args['order'] = 'desc';
			$args['meta_key'] = '';
		} elseif ( 'date' == $orderby_value ) {
			$args['orderby'] = 'date';
			$args['order'] = 'desc';
			$args['meta_key'] = '';
		} elseif ( 'price' == $orderby_value ) {
			$args['orderby'] = 'price';
			$args['order'] = 'desc';
			$args['meta_key'] = '';
		}

		return $args;
	}
}

/**
 * Comment nav
 */

function tz_comment_nav() {
 if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) {
?>
 <nav class="navigation comment-navigation" role="navigation">
	 <h2 class="screen-reader-text"><?php _e( 'Comment navigation', 'jewelry' ); ?></h2>
	 <div class="nav-links">
		 <?php
			 if ( $prev_link = get_previous_comments_link( __( 'Older Comments', 'jewelry' ) ) ) :
				 printf( '<div class="nav-previous">%s</div>', $prev_link );
			 endif;

			 if ( $next_link = get_next_comments_link( __( 'Newer Comments', 'jewelry' ) ) ) :
				 printf( '<div class="nav-next">%s</div>', $next_link );
			 endif;
		 ?>
	 </div><!-- .nav-links -->
 </nav><!-- .comment-navigation -->
<?php
 }
}

/**
 * Include some files
 */

require( 'functions/customizer.php' );
require( 'functions/customizer-textarea.php' );
require( 'functions/customizer-pages.php' );
require( 'functions/metaboxes.php' );
require( 'includes/meta/slide.php' );
require( 'includes/meta/link.php' );
require( 'includes/widgets/widget-social.php' );
require( 'includes/widgets/widget-contact.php' );
require( 'includes/widgets/widget-newsletter.php' );
